chart Package
=============

:mod:`chart` Module
-------------------

.. automodule:: stoqlib.chart.chart
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentcharts` Module
---------------------------

.. automodule:: stoqlib.chart.paymentcharts
    :members:
    :undoc-members:
    :show-inheritance:

